django-siteprefs documentation
==============================

http://github.com/idlesign/django-siteprefs

*Reusable app for Django introducing site preferences system*

django-siteprefs allows Django applications settings to come alive.


Requirements
------------

1. Python 2.7+ or 3.3+
2. Django 1.4+
3. Django Auth contrib enabled
4. Django Admin contrib enabled (optional)
5. South 1.0+ (for automatic DB migrations; not required for Django 1.7+)


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    registration


Get involved into django-siteprefs
----------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-siteprefs/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-siteprefs, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex: https://www.transifex.com/projects/p/django-siteprefs/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.


Also
----

Consider more applications on the subject — https://www.djangopackages.com/grids/g/live-setting/
